summaryrefslogtreecommitdiff
path: root/sw/source/uibase
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/uibase')
-rw-r--r--sw/source/uibase/dochdl/swdtflvr.cxx4
-rw-r--r--sw/source/uibase/docvw/SidebarTxtControl.cxx2
-rw-r--r--sw/source/uibase/docvw/edtdd.cxx4
-rw-r--r--sw/source/uibase/docvw/edtwin.cxx64
-rw-r--r--sw/source/uibase/docvw/edtwin2.cxx40
-rw-r--r--sw/source/uibase/docvw/romenu.cxx2
-rw-r--r--sw/source/uibase/uiview/viewport.cxx2
7 files changed, 59 insertions, 59 deletions
diff --git a/sw/source/uibase/dochdl/swdtflvr.cxx b/sw/source/uibase/dochdl/swdtflvr.cxx
index 8ddf1448c2bd..190afa612de4 100644
--- a/sw/source/uibase/dochdl/swdtflvr.cxx
+++ b/sw/source/uibase/dochdl/swdtflvr.cxx
@@ -453,7 +453,7 @@ bool SwTransferable::GetData( const DataFlavor& rFlavor, const OUString& rDestDo
if( nSelectionType & nsSelectionType::SEL_TXT && !m_pWrtShell->HasMark() )
{
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_INETATTR );
+ SwContentAtPos aContentAtPos( IsAttrAtPos::InetAttr );
Point aPos( SwEditWin::GetDDStartPosX(), SwEditWin::GetDDStartPosY());
@@ -3115,7 +3115,7 @@ void SwTransferable::SetDataForDragAndDrop( const Point& rSttPos )
else if( nSelection & nsSelectionType::SEL_TXT && !m_pWrtShell->HasMark() )
{
// is only one field - selected?
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_INETATTR );
+ SwContentAtPos aContentAtPos( IsAttrAtPos::InetAttr );
Point aPos( SwEditWin::GetDDStartPosX(), SwEditWin::GetDDStartPosY());
if( m_pWrtShell->GetContentAtPos( aPos, aContentAtPos ) )
diff --git a/sw/source/uibase/docvw/SidebarTxtControl.cxx b/sw/source/uibase/docvw/SidebarTxtControl.cxx
index efdd971f5da2..5180568227cf 100644
--- a/sw/source/uibase/docvw/SidebarTxtControl.cxx
+++ b/sw/source/uibase/docvw/SidebarTxtControl.cxx
@@ -119,7 +119,7 @@ void SidebarTextControl::RequestHelp(const HelpEvent &rEvt)
default: nResId = 0;
}
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_REDLINE );
+ SwContentAtPos aContentAtPos( IsAttrAtPos::Redline );
if ( nResId &&
mrDocView.GetWrtShell().GetContentAtPos( mrSidebarWin.GetAnchorPos(), aContentAtPos ) )
{
diff --git a/sw/source/uibase/docvw/edtdd.cxx b/sw/source/uibase/docvw/edtdd.cxx
index f4d8f7c160df..fa6c3caf8370 100644
--- a/sw/source/uibase/docvw/edtdd.cxx
+++ b/sw/source/uibase/docvw/edtdd.cxx
@@ -103,7 +103,7 @@ void SwEditWin::StartDrag( sal_Int8 /*nAction*/, const Point& rPosPixel )
}
else
{
- SwContentAtPos aSwContentAtPos( SwContentAtPos::SW_INETATTR );
+ SwContentAtPos aSwContentAtPos( IsAttrAtPos::InetAttr );
bStart = rSh.GetContentAtPos( aDocPos,
aSwContentAtPos );
}
@@ -446,7 +446,7 @@ sal_Int8 SwEditWin::AcceptDrop( const AcceptDropEvent& rEvt )
SotExchangeDest::SWDOC_FREE_AREA == m_nDropDestination )
{
CleanupDropUserMarker();
- SwContentAtPos aCont( SwContentAtPos::SW_CONTENT_CHECK );
+ SwContentAtPos aCont( IsAttrAtPos::ContentCheck );
if(rSh.GetContentAtPos(aDocPt, aCont))
rSh.SwCursorShell::SetVisibleCursor( aDocPt );
}
diff --git a/sw/source/uibase/docvw/edtwin2.cxx b/sw/source/uibase/docvw/edtwin2.cxx
index 14e031b610c8..5d173185bc04 100644
--- a/sw/source/uibase/docvw/edtwin2.cxx
+++ b/sw/source/uibase/docvw/edtwin2.cxx
@@ -129,42 +129,42 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
if( bContinue && bQuickBalloon)
{
SwRect aFieldRect;
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_FIELD |
- SwContentAtPos::SW_INETATTR |
- SwContentAtPos::SW_FTN |
- SwContentAtPos::SW_REDLINE |
- SwContentAtPos::SW_TOXMARK |
- SwContentAtPos::SW_REFMARK |
- SwContentAtPos::SW_SMARTTAG |
+ SwContentAtPos aContentAtPos( IsAttrAtPos::Field |
+ IsAttrAtPos::InetAttr |
+ IsAttrAtPos::Ftn |
+ IsAttrAtPos::Redline |
+ IsAttrAtPos::ToxMark |
+ IsAttrAtPos::RefMark |
+ IsAttrAtPos::SmartTag |
#ifdef DBG_UTIL
- SwContentAtPos::SW_TABLEBOXVALUE |
- ( bBalloon ? SwContentAtPos::SW_CURR_ATTRS : 0) |
+ IsAttrAtPos::TableBoxValue |
+ ( bBalloon ? IsAttrAtPos::CurrAttrs : IsAttrAtPos::NONE) |
#endif
- SwContentAtPos::SW_TABLEBOXFML );
+ IsAttrAtPos::TableBoxFml );
if( rSh.GetContentAtPos( aPos, aContentAtPos, false, &aFieldRect ) )
{
QuickHelpFlags nStyle = QuickHelpFlags::NONE; // style of quick help
switch( aContentAtPos.eContentAtPos )
{
- case SwContentAtPos::SW_TABLEBOXFML:
+ case IsAttrAtPos::TableBoxFml:
sText = "= ";
sText += static_cast<const SwTableBoxFormula*>(aContentAtPos.aFnd.pAttr)->GetFormula();
break;
#ifdef DBG_UTIL
- case SwContentAtPos::SW_TABLEBOXVALUE:
+ case IsAttrAtPos::TableBoxValue:
{
sText = OStringToOUString(OString::number(
static_cast<const SwTableBoxValue*>(aContentAtPos.aFnd.pAttr)->GetValue()),
osl_getThreadTextEncoding());
}
break;
- case SwContentAtPos::SW_CURR_ATTRS:
+ case IsAttrAtPos::CurrAttrs:
sText = aContentAtPos.sStr;
break;
#endif
- case SwContentAtPos::SW_INETATTR:
+ case IsAttrAtPos::InetAttr:
{
sText = static_cast<const SfxStringItem*>(aContentAtPos.aFnd.pAttr)->GetValue();
sText = URIHelper::removePassword( sText,
@@ -230,7 +230,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
}
break;
}
- case SwContentAtPos::SW_SMARTTAG:
+ case IsAttrAtPos::SmartTag:
{
vcl::KeyCode aCode( KEY_SPACE );
vcl::KeyCode aModifiedCode( KEY_SPACE, KEY_MOD1 );
@@ -241,7 +241,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
}
break;
- case SwContentAtPos::SW_FTN:
+ case IsAttrAtPos::Ftn:
if( aContentAtPos.pFndTextAttr && aContentAtPos.aFnd.pAttr )
{
const SwFormatFootnote* pFootnote = static_cast<const SwFormatFootnote*>(aContentAtPos.aFnd.pAttr);
@@ -255,11 +255,11 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
}
break;
- case SwContentAtPos::SW_REDLINE:
+ case IsAttrAtPos::Redline:
sText = lcl_GetRedlineHelp(*aContentAtPos.aFnd.pRedl, bBalloon);
break;
- case SwContentAtPos::SW_TOXMARK:
+ case IsAttrAtPos::ToxMark:
sText = aContentAtPos.sStr;
if( !sText.isEmpty() && aContentAtPos.pFndTextAttr )
{
@@ -272,7 +272,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
}
}
break;
- case SwContentAtPos::SW_REFMARK:
+ case IsAttrAtPos::RefMark:
if(aContentAtPos.aFnd.pAttr)
{
sText = SW_RESSTR(STR_CONTENT_TYPE_SINGLE_REFERENCE);
@@ -356,7 +356,7 @@ void SwEditWin::RequestHelp(const HelpEvent &rEvt)
if( sText.isEmpty() )
{
- aContentAtPos.eContentAtPos = SwContentAtPos::SW_REDLINE;
+ aContentAtPos.eContentAtPos = IsAttrAtPos::Redline;
if( rSh.GetContentAtPos( aPos, aContentAtPos, false, &aFieldRect ) )
sText = lcl_GetRedlineHelp(*aContentAtPos.aFnd.pRedl, bBalloon);
}
diff --git a/sw/source/uibase/docvw/romenu.cxx b/sw/source/uibase/docvw/romenu.cxx
index 3e48e067a8f8..3f494bdb4b39 100644
--- a/sw/source/uibase/docvw/romenu.cxx
+++ b/sw/source/uibase/docvw/romenu.cxx
@@ -97,7 +97,7 @@ SwReadOnlyPopup::SwReadOnlyPopup( const Point &rDPos, SwView &rV ) :
rSh.IsURLGrfAtPos( rDocPos, &sURL, &sTargetFrameName, &sDescription );
if ( sURL.isEmpty() )
{
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_INETATTR );
+ SwContentAtPos aContentAtPos( IsAttrAtPos::InetAttr );
if( rSh.GetContentAtPos( rDocPos, aContentAtPos))
{
const SwFormatINetFormat &rIItem = *static_cast<const SwFormatINetFormat*>(aContentAtPos.aFnd.pAttr);
diff --git a/sw/source/uibase/uiview/viewport.cxx b/sw/source/uibase/uiview/viewport.cxx
index 0c8e7dff8f65..477ce1f18899 100644
--- a/sw/source/uibase/uiview/viewport.cxx
+++ b/sw/source/uibase/uiview/viewport.cxx
@@ -721,7 +721,7 @@ IMPL_LINK( SwView, ScrollHdl, ScrollBar *, p, void )
aRect.Bottom() = aRect.Top();
OUString sPageStr( GetPageStr( nPhNum, nVirtNum, sDisplay ));
- SwContentAtPos aCnt( SwContentAtPos::SW_OUTLINE );
+ SwContentAtPos aCnt( IsAttrAtPos::Outline );
bool bSuccess = m_pWrtShell->GetContentAtPos(aPos, aCnt);
if (bSuccess && !aCnt.sStr.isEmpty())
{
diff --git a/sw/source/uibase/docvw/edtwin.cxx b/sw/source/uibase/docvw/edtwin.cxx
index a5a350f936ce..1ac0c293d2ac 100644
--- a/sw/source/uibase/docvw/edtwin.cxx
+++ b/sw/source/uibase/docvw/edtwin.cxx
@@ -560,19 +560,19 @@ void SwEditWin::UpdatePointer(const Point &rLPt, sal_uInt16 nModifier )
else
{
// Even if we already have something, prefer URLs if possible.
- SwContentAtPos aUrlPos(SwContentAtPos::SW_INETATTR);
+ SwContentAtPos aUrlPos(IsAttrAtPos::InetAttr);
if (bCntAtPos || rSh.GetContentAtPos(rLPt, aUrlPos))
{
SwContentAtPos aSwContentAtPos(
- SwContentAtPos::SW_FIELD |
- SwContentAtPos::SW_CLICKFIELD |
- SwContentAtPos::SW_INETATTR |
- SwContentAtPos::SW_FTN |
- SwContentAtPos::SW_SMARTTAG );
+ IsAttrAtPos::Field |
+ IsAttrAtPos::ClickField |
+ IsAttrAtPos::InetAttr |
+ IsAttrAtPos::Ftn |
+ IsAttrAtPos::SmartTag );
if( rSh.GetContentAtPos( rLPt, aSwContentAtPos) )
{
// Is edit inline input field
- if (SwContentAtPos::SW_FIELD == aSwContentAtPos.eContentAtPos)
+ if (IsAttrAtPos::Field == aSwContentAtPos.eContentAtPos)
{
if ( aSwContentAtPos.pFndTextAttr != nullptr
&& aSwContentAtPos.pFndTextAttr->Which() == RES_TXTATR_INPUTFIELD)
@@ -584,11 +584,11 @@ void SwEditWin::UpdatePointer(const Point &rLPt, sal_uInt16 nModifier )
}
else
{
- const bool bClickToFollow = SwContentAtPos::SW_INETATTR == aSwContentAtPos.eContentAtPos ||
- SwContentAtPos::SW_SMARTTAG == aSwContentAtPos.eContentAtPos;
+ const bool bClickToFollow = IsAttrAtPos::InetAttr == aSwContentAtPos.eContentAtPos ||
+ IsAttrAtPos::SmartTag == aSwContentAtPos.eContentAtPos;
if( !bClickToFollow ||
- (SwContentAtPos::SW_INETATTR == aSwContentAtPos.eContentAtPos && bExecHyperlinks) ||
- (SwContentAtPos::SW_SMARTTAG == aSwContentAtPos.eContentAtPos && bExecSmarttags) )
+ (IsAttrAtPos::InetAttr == aSwContentAtPos.eContentAtPos && bExecHyperlinks) ||
+ (IsAttrAtPos::SmartTag == aSwContentAtPos.eContentAtPos && bExecSmarttags) )
eStyle = PointerStyle::RefHand;
}
}
@@ -2736,7 +2736,7 @@ void SwEditWin::RstMBDownFlags()
*/
static bool lcl_urlOverBackground(SwWrtShell& rSh, const Point& rDocPos)
{
- SwContentAtPos aSwContentAtPos(SwContentAtPos::SW_INETATTR);
+ SwContentAtPos aSwContentAtPos(IsAttrAtPos::InetAttr);
SdrObject* pSelectableObj = rSh.GetObjAt(rDocPos);
return rSh.GetContentAtPos(rDocPos, aSwContentAtPos) && pSelectableObj->GetLayer() == rSh.GetDoc()->getIDocumentDrawModelAccess().GetHellId();
@@ -3598,8 +3598,8 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
if( bExecHyperlinks )
{
SwContentAtPos aContentAtPos(
- SwContentAtPos::SW_FTN |
- SwContentAtPos::SW_INETATTR );
+ IsAttrAtPos::Ftn |
+ IsAttrAtPos::InetAttr );
if( rSh.GetContentAtPos( aDocPos, aContentAtPos ) )
{
@@ -3625,8 +3625,8 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
default:
if( !rSh.IsViewLocked() )
{
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_CLICKFIELD |
- SwContentAtPos::SW_INETATTR );
+ SwContentAtPos aContentAtPos( IsAttrAtPos::ClickField |
+ IsAttrAtPos::InetAttr );
if( rSh.GetContentAtPos( aDocPos, aContentAtPos ) &&
!rSh.IsReadOnlyAvailable() &&
aContentAtPos.IsInProtectSect() )
@@ -3640,7 +3640,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
rSh.ClearGCAttr();
}
- SwContentAtPos aFieldAtPos(SwContentAtPos::SW_FIELD);
+ SwContentAtPos aFieldAtPos(IsAttrAtPos::Field);
bool bEditableFieldClicked = false;
// Are we clicking on a field?
@@ -3717,7 +3717,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
&& static_cast< sal_uInt8 >(rMEvt.GetClicks() % 4) == 1
&& !rSh.TestCurrPam( aDocPos ) )
{
- SwContentAtPos aFieldAtPos(SwContentAtPos::SW_FIELD);
+ SwContentAtPos aFieldAtPos(IsAttrAtPos::Field);
// Are we clicking on a field?
if (g_bValidCursorPos
@@ -4163,9 +4163,9 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
break;
}
// change ui if mouse is over SwPostItField
// TODO: do the same thing for redlines SW_REDLINE
SwRect aFieldRect;
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_FIELD);
+ SwContentAtPos aContentAtPos( IsAttrAtPos::Field);
if( rSh.GetContentAtPos( aDocPt, aContentAtPos, false, &aFieldRect ) )
{
const SwField* pField = aContentAtPos.aFnd.pField;
@@ -4191,7 +4191,7 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
const SwFrameFormat* pFormat = nullptr;
const SwFormatINetFormat* pINet = nullptr;
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_INETATTR );
+ SwContentAtPos aContentAtPos( IsAttrAtPos::InetAttr );
if( rSh.GetContentAtPos( aDocPt, aContentAtPos ) )
pINet = static_cast<const SwFormatINetFormat*>(aContentAtPos.aFnd.pAttr);
@@ -4556,7 +4556,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
}
else
{
- SwContentAtPos aFieldAtPos ( SwContentAtPos::SW_FIELD );
+ SwContentAtPos aFieldAtPos ( IsAttrAtPos::Field );
if ( !rSh.IsInSelect() && rSh.TestCurrPam( aDocPt ) &&
!rSh.GetContentAtPos( aDocPt, aFieldAtPos ) )
{
@@ -4598,15 +4598,15 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
if(m_pApplyTempl)
bExecHyperlinks = false;
- SwContentAtPos aContentAtPos( SwContentAtPos::SW_FIELD |
- SwContentAtPos::SW_INETATTR |
- SwContentAtPos::SW_SMARTTAG | SwContentAtPos::SW_FORMCTRL);
+ SwContentAtPos aContentAtPos( IsAttrAtPos::Field |
+ IsAttrAtPos::InetAttr |
+ IsAttrAtPos::SmartTag | IsAttrAtPos::FormControl);
if( rSh.GetContentAtPos( aDocPt, aContentAtPos ) )
{
// Do it again if we're not on a field/hyperlink to update the cursor accordingly
- if ( SwContentAtPos::SW_FIELD != aContentAtPos.eContentAtPos
- && SwContentAtPos::SW_INETATTR != aContentAtPos.eContentAtPos )
+ if ( IsAttrAtPos::Field != aContentAtPos.eContentAtPos
+ && IsAttrAtPos::InetAttr != aContentAtPos.eContentAtPos )
rSh.GetContentAtPos( aDocPt, aContentAtPos, true );
bool bViewLocked = rSh.IsViewLocked();
@@ -4616,7 +4616,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
ReleaseMouse();
- if( SwContentAtPos::SW_FIELD == aContentAtPos.eContentAtPos )
+ if( IsAttrAtPos::Field == aContentAtPos.eContentAtPos )
{
bool bAddMode(false);
// AdditionalMode if applicable
@@ -4655,13 +4655,13 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
rSh.LeaveAddMode();
}
}
- else if ( SwContentAtPos::SW_SMARTTAG == aContentAtPos.eContentAtPos )
+ else if ( IsAttrAtPos::SmartTag == aContentAtPos.eContentAtPos )
{
// execute smarttag menu
if ( bExecSmarttags && SwSmartTagMgr::Get().IsSmartTagsEnabled() )
m_rView.ExecSmartTagPopup( aDocPt );
}
- else if ( SwContentAtPos::SW_FORMCTRL == aContentAtPos.eContentAtPos )
+ else if ( IsAttrAtPos::FormControl == aContentAtPos.eContentAtPos )
{
OSL_ENSURE( aContentAtPos.aFnd.pFieldmark != nullptr, "where is my field ptr???");
if ( aContentAtPos.aFnd.pFieldmark != nullptr)
@@ -4682,7 +4682,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
}
}
}
- else if ( SwContentAtPos::SW_INETATTR == aContentAtPos.eContentAtPos )
+ else if ( IsAttrAtPos::InetAttr == aContentAtPos.eContentAtPos )
{
if ( bExecHyperlinks && aContentAtPos.aFnd.pAttr )
rSh.ClickToINetAttr( *static_cast<const SwFormatINetFormat*>(aContentAtPos.aFnd.pAttr), nFilter );
@@ -4693,7 +4693,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
}
else
{
- aContentAtPos = SwContentAtPos( SwContentAtPos::SW_FTN );
+ aContentAtPos = SwContentAtPos( IsAttrAtPos::Ftn );
if( !rSh.GetContentAtPos( aDocPt, aContentAtPos, true ) && bExecHyperlinks )
{
SdrViewEvent aVEvt;
@@ -4163,9 +4163,9 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
}
// change ui if mouse is over SwPostItField
- // TODO: do the same thing for redlines SW_REDLINE
+ // TODO: do the same thing for redlines IsAttrAtPos::Redline
SwRect aFieldRect;